[evolution] Bug 735747 - Follow GNOME notification settings under gnome-shell



commit 12aa868eff3d757f13924da510ca6ced230a7bf1
Author: Milan Crha <mcrha redhat com>
Date:   Mon Oct 26 12:44:42 2015 +0100

    Bug 735747 - Follow GNOME notification settings under gnome-shell

 plugins/mail-notification/mail-notification.c |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)
---
diff --git a/plugins/mail-notification/mail-notification.c b/plugins/mail-notification/mail-notification.c
index 35ace49..5edbdb3 100644
--- a/plugins/mail-notification/mail-notification.c
+++ b/plugins/mail-notification/mail-notification.c
@@ -632,9 +632,11 @@ new_notify_sound (EMEventTargetFolder *t)
 
        time (&last_newmail);
 
-       /* just put it to the idle queue */
+       /* just put it to the idle queue, if not under GNOME, where everything is
+          handled by the libnotify */
        if (data.notify_idle_id == 0 &&
-               (last_newmail - data.last_notify >= NOTIFY_THROTTLE))
+           (last_newmail - data.last_notify >= NOTIFY_THROTTLE) &&
+           !e_util_is_running_gnome ())
                data.notify_idle_id = g_idle_add_full (
                        G_PRIORITY_LOW, sound_notify_idle_cb, &data, NULL);
 }


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]